from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.bank.v1beta1 import bank_pb2 as _bank_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.cosmos.query.v1 import query_pb2 as _query_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryBalanceRequest(_message.Message):
    __slots__ = ("address", "denom")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    address: str
    denom: str
    def __init__(self, address: _Optional[str] = ..., denom: _Optional[str] = ...) -> None: ...

class QueryBalanceResponse(_message.Message):
    __slots__ = ("balance",)
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    balance: _coin_pb2.Coin
    def __init__(self, balance: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryAllBalancesRequest(_message.Message):
    __slots__ = ("address", "pagination", "resolve_denom")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    RESOLVE_DENOM_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    resolve_denom: bool
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ..., resolve_denom: bool = ...) -> None: ...

class QueryAllBalancesResponse(_message.Message):
    __slots__ = ("balances", "pagination")
    BALANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    balances: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, balances: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySpendableBalancesRequest(_message.Message):
    __slots__ = ("address", "pagination")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    address: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, address: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySpendableBalancesResponse(_message.Message):
    __slots__ = ("balances", "pagination")
    BALANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    balances: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, balances: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySpendableBalanceByDenomRequest(_message.Message):
    __slots__ = ("address", "denom")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DENOM_FIELD_NUMBER: _ClassVar[int]
    address: str
    denom: str
    def __init__(self, address: _Optional[str] = ..., denom: _Optional[str] = ...) -> None: ...

class QuerySpendableBalanceByDenomResponse(_message.Message):
    __slots__ = ("balance",)
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    balance: _coin_pb2.Coin
    def __init__(self, balance: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryTotalSupplyRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryTotalSupplyResponse(_message.Message):
    __slots__ = ("supply", "pagination")
    SUPPLY_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    supply: _containers.RepeatedCompositeFieldContainer[_coin_pb2.Coin]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, supply: _Optional[_Iterable[_Union[_coin_pb2.Coin, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySupplyOfRequest(_message.Message):
    __slots__ = ("denom",)
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QuerySupplyOfResponse(_message.Message):
    __slots__ = ("amount",)
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    amount: _coin_pb2.Coin
    def __init__(self, amount: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _bank_pb2.Params
    def __init__(self, params: _Optional[_Union[_bank_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryDenomsMetadataRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryDenomsMetadataResponse(_message.Message):
    __slots__ = ("metadatas", "pagination")
    METADATAS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    metadatas: _containers.RepeatedCompositeFieldContainer[_bank_pb2.Metadata]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, metadatas: _Optional[_Iterable[_Union[_bank_pb2.Metadata, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDenomMetadataRequest(_message.Message):
    __slots__ = ("denom",)
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QueryDenomMetadataResponse(_message.Message):
    __slots__ = ("metadata",)
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _bank_pb2.Metadata
    def __init__(self, metadata: _Optional[_Union[_bank_pb2.Metadata, _Mapping]] = ...) -> None: ...

class QueryDenomMetadataByQueryStringRequest(_message.Message):
    __slots__ = ("denom",)
    DENOM_FIELD_NUMBER: _ClassVar[int]
    denom: str
    def __init__(self, denom: _Optional[str] = ...) -> None: ...

class QueryDenomMetadataByQueryStringResponse(_message.Message):
    __slots__ = ("metadata",)
    METADATA_FIELD_NUMBER: _ClassVar[int]
    metadata: _bank_pb2.Metadata
    def __init__(self, metadata: _Optional[_Union[_bank_pb2.Metadata, _Mapping]] = ...) -> None: ...

class QueryDenomOwnersRequest(_message.Message):
    __slots__ = ("denom", "pagination")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    denom: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, denom: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class DenomOwner(_message.Message):
    __slots__ = ("address", "balance")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    BALANCE_FIELD_NUMBER: _ClassVar[int]
    address: str
    balance: _coin_pb2.Coin
    def __init__(self, address: _Optional[str] = ..., balance: _Optional[_Union[_coin_pb2.Coin, _Mapping]] = ...) -> None: ...

class QueryDenomOwnersResponse(_message.Message):
    __slots__ = ("denom_owners", "pagination")
    DENOM_OWNERS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    denom_owners: _containers.RepeatedCompositeFieldContainer[DenomOwner]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, denom_owners: _Optional[_Iterable[_Union[DenomOwner, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QuerySendEnabledRequest(_message.Message):
    __slots__ = ("denoms", "pagination")
    DENOMS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    denoms: _containers.RepeatedScalarFieldContainer[str]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, denoms: _Optional[_Iterable[str]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QuerySendEnabledResponse(_message.Message):
    __slots__ = ("send_enabled", "pagination")
    SEND_ENABLED_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    send_enabled: _containers.RepeatedCompositeFieldContainer[_bank_pb2.SendEnabled]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, send_enabled: _Optional[_Iterable[_Union[_bank_pb2.SendEnabled, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.cosmos.base.reflection.v2alpha1 import reflection_pb2 as cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in cosmos/base/reflection/v2alpha1/reflection_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ReflectionServiceStub(object):
    """ReflectionService defines a service for application reflection.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAuthnDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetAuthnDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorResponse.FromString,
                _registered_method=True)
        self.GetChainDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetChainDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorResponse.FromString,
                _registered_method=True)
        self.GetCodecDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetCodecDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorResponse.FromString,
                _registered_method=True)
        self.GetConfigurationDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetConfigurationDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorResponse.FromString,
                _registered_method=True)
        self.GetQueryServicesDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetQueryServicesDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorResponse.FromString,
                _registered_method=True)
        self.GetTxDescriptor = channel.unary_unary(
                '/cosmos.base.reflection.v2alpha1.ReflectionService/GetTxDescriptor',
                request_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorRequest.SerializeToString,
                response_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorResponse.FromString,
                _registered_method=True)


class ReflectionServiceServicer(object):
    """ReflectionService defines a service for application reflection.
    """

    def GetAuthnDescriptor(self, request, context):
        """GetAuthnDescriptor returns information on how to authenticate transactions in the application
        NOTE: this RPC is still experimental and might be subject to breaking changes or removal in
        future releases of the cosmos-sdk.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChainDescriptor(self, request, context):
        """GetChainDescriptor returns the description of the chain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCodecDescriptor(self, request, context):
        """GetCodecDescriptor returns the descriptor of the codec of the application
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConfigurationDescriptor(self, request, context):
        """GetConfigurationDescriptor returns the descriptor for the sdk.Config of the application
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQueryServicesDescriptor(self, request, context):
        """GetQueryServicesDescriptor returns the available gRPC queryable services of the application
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTxDescriptor(self, request, context):
        """GetTxDescriptor returns information on the used transaction object and available msgs that can be used
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReflectionServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAuthnDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAuthnDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorResponse.SerializeToString,
            ),
            'GetChainDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChainDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorResponse.SerializeToString,
            ),
            'GetCodecDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCodecDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorResponse.SerializeToString,
            ),
            'GetConfigurationDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConfigurationDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorResponse.SerializeToString,
            ),
            'GetQueryServicesDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQueryServicesDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorResponse.SerializeToString,
            ),
            'GetTxDescriptor': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTxDescriptor,
                    request_deserializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorRequest.FromString,
                    response_serializer=cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.base.reflection.v2alpha1.ReflectionService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.base.reflection.v2alpha1.ReflectionService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ReflectionService(object):
    """ReflectionService defines a service for application reflection.
    """

    @staticmethod
    def GetAuthnDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetAuthnDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetAuthnDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetChainDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetChainDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetChainDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetCodecDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetCodecDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetCodecDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConfigurationDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetConfigurationDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetConfigurationDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetQueryServicesDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetQueryServicesDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetQueryServicesDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTxDescriptor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.base.reflection.v2alpha1.ReflectionService/GetTxDescriptor',
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorRequest.SerializeToString,
            cosmos_dot_base_dot_reflection_dot_v2alpha1_dot_reflection__pb2.GetTxDescriptorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from v4_proto.cosmos.app.v1alpha1 import module_pb2 as _module_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Module(_message.Message):
    __slots__ = ("blocked_module_accounts_override", "authority")
    BLOCKED_MODULE_ACCOUNTS_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    AUTHORITY_FIELD_NUMBER: _ClassVar[int]
    blocked_module_accounts_override: _containers.RepeatedScalarFieldContainer[str]
    authority: str
    def __init__(self, blocked_module_accounts_override: _Optional[_Iterable[str]] = ..., authority: _Optional[str] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class BlockMessageIds(_message.Message):
    __slots__ = ("ids",)
    IDS_FIELD_NUMBER: _ClassVar[int]
    ids: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, ids: _Optional[_Iterable[int]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Coin(_message.Message):
    __slots__ = ("denom", "amount")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    denom: str
    amount: str
    def __init__(self, denom: _Optional[str] = ..., amount: _Optional[str] = ...) -> None: ...

class DecCoin(_message.Message):
    __slots__ = ("denom", "amount")
    DENOM_FIELD_NUMBER: _ClassVar[int]
    AMOUNT_FIELD_NUMBER: _ClassVar[int]
    denom: str
    amount: str
    def __init__(self, denom: _Optional[str] = ..., amount: _Optional[str] = ...) -> None: ...

class IntProto(_message.Message):
    __slots__ = ("int",)
    INT_FIELD_NUMBER: _ClassVar[int]
    int: str
    def __init__(self, int: _Optional[str] = ...) -> None: ...

class DecProto(_message.Message):
    __slots__ = ("dec",)
    DEC_FIELD_NUMBER: _ClassVar[int]
    dec: str
    def __init__(self, dec: _Optional[str] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.dydxprotocol.prices import market_param_pb2 as _market_param_pb2
from v4_proto.dydxprotocol.prices import market_price_pb2 as _market_price_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryMarketPriceRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryMarketPriceResponse(_message.Message):
    __slots__ = ("market_price",)
    MARKET_PRICE_FIELD_NUMBER: _ClassVar[int]
    market_price: _market_price_pb2.MarketPrice
    def __init__(self, market_price: _Optional[_Union[_market_price_pb2.MarketPrice, _Mapping]] = ...) -> None: ...

class QueryAllMarketPricesRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllMarketPricesResponse(_message.Message):
    __slots__ = ("market_prices", "pagination")
    MARKET_PRICES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    market_prices: _containers.RepeatedCompositeFieldContainer[_market_price_pb2.MarketPrice]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, market_prices: _Optional[_Iterable[_Union[_market_price_pb2.MarketPrice, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryMarketParamRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: int
    def __init__(self, id: _Optional[int] = ...) -> None: ...

class QueryMarketParamResponse(_message.Message):
    __slots__ = ("market_param",)
    MARKET_PARAM_FIELD_NUMBER: _ClassVar[int]
    market_param: _market_param_pb2.MarketParam
    def __init__(self, market_param: _Optional[_Union[_market_param_pb2.MarketParam, _Mapping]] = ...) -> None: ...

class QueryAllMarketParamsRequest(_message.Message):
    __slots__ = ("pagination",)
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    pagination: _pagination_pb2.PageRequest
    def __init__(self, pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllMarketParamsResponse(_message.Message):
    __slots__ = ("market_params", "pagination")
    MARKET_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    market_params: _containers.RepeatedCompositeFieldContainer[_market_param_pb2.MarketParam]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, market_params: _Optional[_Iterable[_Union[_market_param_pb2.MarketParam, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.cosmos.crypto.multisig.v1beta1 import multisig_pb2 as _multisig_pb2
from google.protobuf import any_pb2 as _any_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SignMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SIGN_MODE_UNSPECIFIED: _ClassVar[SignMode]
    SIGN_MODE_DIRECT: _ClassVar[SignMode]
    SIGN_MODE_TEXTUAL: _ClassVar[SignMode]
    SIGN_MODE_DIRECT_AUX: _ClassVar[SignMode]
    SIGN_MODE_LEGACY_AMINO_JSON: _ClassVar[SignMode]
    SIGN_MODE_EIP_191: _ClassVar[SignMode]
SIGN_MODE_UNSPECIFIED: SignMode
SIGN_MODE_DIRECT: SignMode
SIGN_MODE_TEXTUAL: SignMode
SIGN_MODE_DIRECT_AUX: SignMode
SIGN_MODE_LEGACY_AMINO_JSON: SignMode
SIGN_MODE_EIP_191: SignMode

class SignatureDescriptors(_message.Message):
    __slots__ = ("signatures",)
    SIGNATURES_FIELD_NUMBER: _ClassVar[int]
    signatures: _containers.RepeatedCompositeFieldContainer[SignatureDescriptor]
    def __init__(self, signatures: _Optional[_Iterable[_Union[SignatureDescriptor, _Mapping]]] = ...) -> None: ...

class SignatureDescriptor(_message.Message):
    __slots__ = ("public_key", "data", "sequence")
    class Data(_message.Message):
        __slots__ = ("single", "multi")
        class Single(_message.Message):
            __slots__ = ("mode", "signature")
            MODE_FIELD_NUMBER: _ClassVar[int]
            SIGNATURE_FIELD_NUMBER: _ClassVar[int]
            mode: SignMode
            signature: bytes
            def __init__(self, mode: _Optional[_Union[SignMode, str]] = ..., signature: _Optional[bytes] = ...) -> None: ...
        class Multi(_message.Message):
            __slots__ = ("bitarray", "signatures")
            BITARRAY_FIELD_NUMBER: _ClassVar[int]
            SIGNATURES_FIELD_NUMBER: _ClassVar[int]
            bitarray: _multisig_pb2.CompactBitArray
            signatures: _containers.RepeatedCompositeFieldContainer[SignatureDescriptor.Data]
            def __init__(self, bitarray: _Optional[_Union[_multisig_pb2.CompactBitArray, _Mapping]] = ..., signatures: _Optional[_Iterable[_Union[SignatureDescriptor.Data, _Mapping]]] = ...) -> None: ...
        SINGLE_FIELD_NUMBER: _ClassVar[int]
        MULTI_FIELD_NUMBER: _ClassVar[int]
        single: SignatureDescriptor.Data.Single
        multi: SignatureDescriptor.Data.Multi
        def __init__(self, single: _Optional[_Union[SignatureDescriptor.Data.Single, _Mapping]] = ..., multi: _Optional[_Union[SignatureDescriptor.Data.Multi, _Mapping]] = ...) -> None: ...
    PUBLIC_KEY_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    public_key: _any_pb2.Any
    data: SignatureDescriptor.Data
    sequence: int
    def __init__(self, public_key: _Optional[_Union[_any_pb2.Any, _Mapping]] = ..., data: _Optional[_Union[SignatureDescriptor.Data, _Mapping]] = ..., sequence: _Optional[int] = ...) -> None: ...



from v4_proto.cosmos.feegrant.v1beta1 import feegrant_pb2 as _feegrant_pb2
from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryAllowanceRequest(_message.Message):
    __slots__ = ("granter", "grantee")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    granter: str
    grantee: str
    def __init__(self, granter: _Optional[str] = ..., grantee: _Optional[str] = ...) -> None: ...

class QueryAllowanceResponse(_message.Message):
    __slots__ = ("allowance",)
    ALLOWANCE_FIELD_NUMBER: _ClassVar[int]
    allowance: _feegrant_pb2.Grant
    def __init__(self, allowance: _Optional[_Union[_feegrant_pb2.Grant, _Mapping]] = ...) -> None: ...

class QueryAllowancesRequest(_message.Message):
    __slots__ = ("grantee", "pagination")
    GRANTEE_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    grantee: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, grantee: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllowancesResponse(_message.Message):
    __slots__ = ("allowances", "pagination")
    ALLOWANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    allowances: _containers.RepeatedCompositeFieldContainer[_feegrant_pb2.Grant]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, allowances: _Optional[_Iterable[_Union[_feegrant_pb2.Grant, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryAllowancesByGranterRequest(_message.Message):
    __slots__ = ("granter", "pagination")
    GRANTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    granter: str
    pagination: _pagination_pb2.PageRequest
    def __init__(self, granter: _Optional[str] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryAllowancesByGranterResponse(_message.Message):
    __slots__ = ("allowances", "pagination")
    ALLOWANCES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    allowances: _containers.RepeatedCompositeFieldContainer[_feegrant_pb2.Grant]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, allowances: _Optional[_Iterable[_Union[_feegrant_pb2.Grant, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from google.protobuf import any_pb2 as _any_pb2
from v4_proto.cosmos.group.v1 import types_pb2 as _types_pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as _msg_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Exec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    EXEC_UNSPECIFIED: _ClassVar[Exec]
    EXEC_TRY: _ClassVar[Exec]
EXEC_UNSPECIFIED: Exec
EXEC_TRY: Exec

class MsgCreateGroup(_message.Message):
    __slots__ = ("admin", "members", "metadata")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    admin: str
    members: _containers.RepeatedCompositeFieldContainer[_types_pb2.MemberRequest]
    metadata: str
    def __init__(self, admin: _Optional[str] = ..., members: _Optional[_Iterable[_Union[_types_pb2.MemberRequest, _Mapping]]] = ..., metadata: _Optional[str] = ...) -> None: ...

class MsgCreateGroupResponse(_message.Message):
    __slots__ = ("group_id",)
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    def __init__(self, group_id: _Optional[int] = ...) -> None: ...

class MsgUpdateGroupMembers(_message.Message):
    __slots__ = ("admin", "group_id", "member_updates")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    MEMBER_UPDATES_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_id: int
    member_updates: _containers.RepeatedCompositeFieldContainer[_types_pb2.MemberRequest]
    def __init__(self, admin: _Optional[str] = ..., group_id: _Optional[int] = ..., member_updates: _Optional[_Iterable[_Union[_types_pb2.MemberRequest, _Mapping]]] = ...) -> None: ...

class MsgUpdateGroupMembersResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateGroupAdmin(_message.Message):
    __slots__ = ("admin", "group_id", "new_admin")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    NEW_ADMIN_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_id: int
    new_admin: str
    def __init__(self, admin: _Optional[str] = ..., group_id: _Optional[int] = ..., new_admin: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupAdminResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateGroupMetadata(_message.Message):
    __slots__ = ("admin", "group_id", "metadata")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_id: int
    metadata: str
    def __init__(self, admin: _Optional[str] = ..., group_id: _Optional[int] = ..., metadata: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupMetadataResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreateGroupPolicy(_message.Message):
    __slots__ = ("admin", "group_id", "metadata", "decision_policy")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    DECISION_POLICY_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_id: int
    metadata: str
    decision_policy: _any_pb2.Any
    def __init__(self, admin: _Optional[str] = ..., group_id: _Optional[int] = ..., metadata: _Optional[str] = ..., decision_policy: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgCreateGroupPolicyResponse(_message.Message):
    __slots__ = ("address",)
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    address: str
    def __init__(self, address: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupPolicyAdmin(_message.Message):
    __slots__ = ("admin", "group_policy_address", "new_admin")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    NEW_ADMIN_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_policy_address: str
    new_admin: str
    def __init__(self, admin: _Optional[str] = ..., group_policy_address: _Optional[str] = ..., new_admin: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupPolicyAdminResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgCreateGroupWithPolicy(_message.Message):
    __slots__ = ("admin", "members", "group_metadata", "group_policy_metadata", "group_policy_as_admin", "decision_policy")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    GROUP_METADATA_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_METADATA_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_AS_ADMIN_FIELD_NUMBER: _ClassVar[int]
    DECISION_POLICY_FIELD_NUMBER: _ClassVar[int]
    admin: str
    members: _containers.RepeatedCompositeFieldContainer[_types_pb2.MemberRequest]
    group_metadata: str
    group_policy_metadata: str
    group_policy_as_admin: bool
    decision_policy: _any_pb2.Any
    def __init__(self, admin: _Optional[str] = ..., members: _Optional[_Iterable[_Union[_types_pb2.MemberRequest, _Mapping]]] = ..., group_metadata: _Optional[str] = ..., group_policy_metadata: _Optional[str] = ..., group_policy_as_admin: bool = ..., decision_policy: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgCreateGroupWithPolicyResponse(_message.Message):
    __slots__ = ("group_id", "group_policy_address")
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    group_id: int
    group_policy_address: str
    def __init__(self, group_id: _Optional[int] = ..., group_policy_address: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupPolicyDecisionPolicy(_message.Message):
    __slots__ = ("admin", "group_policy_address", "decision_policy")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    DECISION_POLICY_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_policy_address: str
    decision_policy: _any_pb2.Any
    def __init__(self, admin: _Optional[str] = ..., group_policy_address: _Optional[str] = ..., decision_policy: _Optional[_Union[_any_pb2.Any, _Mapping]] = ...) -> None: ...

class MsgUpdateGroupPolicyDecisionPolicyResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgUpdateGroupPolicyMetadata(_message.Message):
    __slots__ = ("admin", "group_policy_address", "metadata")
    ADMIN_FIELD_NUMBER: _ClassVar[int]
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    admin: str
    group_policy_address: str
    metadata: str
    def __init__(self, admin: _Optional[str] = ..., group_policy_address: _Optional[str] = ..., metadata: _Optional[str] = ...) -> None: ...

class MsgUpdateGroupPolicyMetadataResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgSubmitProposal(_message.Message):
    __slots__ = ("group_policy_address", "proposers", "metadata", "messages", "exec", "title", "summary")
    GROUP_POLICY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    PROPOSERS_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    MESSAGES_FIELD_NUMBER: _ClassVar[int]
    EXEC_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    group_policy_address: str
    proposers: _containers.RepeatedScalarFieldContainer[str]
    metadata: str
    messages: _containers.RepeatedCompositeFieldContainer[_any_pb2.Any]
    exec: Exec
    title: str
    summary: str
    def __init__(self, group_policy_address: _Optional[str] = ..., proposers: _Optional[_Iterable[str]] = ..., metadata: _Optional[str] = ..., messages: _Optional[_Iterable[_Union[_any_pb2.Any, _Mapping]]] = ..., exec: _Optional[_Union[Exec, str]] = ..., title: _Optional[str] = ..., summary: _Optional[str] = ...) -> None: ...

class MsgSubmitProposalResponse(_message.Message):
    __slots__ = ("proposal_id",)
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    def __init__(self, proposal_id: _Optional[int] = ...) -> None: ...

class MsgWithdrawProposal(_message.Message):
    __slots__ = ("proposal_id", "address")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    address: str
    def __init__(self, proposal_id: _Optional[int] = ..., address: _Optional[str] = ...) -> None: ...

class MsgWithdrawProposalResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgVote(_message.Message):
    __slots__ = ("proposal_id", "voter", "option", "metadata", "exec")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    VOTER_FIELD_NUMBER: _ClassVar[int]
    OPTION_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    EXEC_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    voter: str
    option: _types_pb2.VoteOption
    metadata: str
    exec: Exec
    def __init__(self, proposal_id: _Optional[int] = ..., voter: _Optional[str] = ..., option: _Optional[_Union[_types_pb2.VoteOption, str]] = ..., metadata: _Optional[str] = ..., exec: _Optional[_Union[Exec, str]] = ...) -> None: ...

class MsgVoteResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MsgExec(_message.Message):
    __slots__ = ("proposal_id", "executor")
    PROPOSAL_ID_FIELD_NUMBER: _ClassVar[int]
    EXECUTOR_FIELD_NUMBER: _ClassVar[int]
    proposal_id: int
    executor: str
    def __init__(self, proposal_id: _Optional[int] = ..., executor: _Optional[str] = ...) -> None: ...

class MsgExecResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: _types_pb2.ProposalExecutorResult
    def __init__(self, result: _Optional[_Union[_types_pb2.ProposalExecutorResult, str]] = ...) -> None: ...

class MsgLeaveGroup(_message.Message):
    __slots__ = ("address", "group_id")
    ADDRESS_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    address: str
    group_id: int
    def __init__(self, address: _Optional[str] = ..., group_id: _Optional[int] = ...) -> None: ...

class MsgLeaveGroupResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from v4_proto.cosmos.base.query.v1beta1 import pagination_pb2 as _pagination_pb2
from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.google.api import annotations_pb2 as _annotations_pb2
from v4_proto.cosmos.base.v1beta1 import coin_pb2 as _coin_pb2
from v4_proto.cosmos.distribution.v1beta1 import distribution_pb2 as _distribution_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class QueryParamsRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryParamsResponse(_message.Message):
    __slots__ = ("params",)
    PARAMS_FIELD_NUMBER: _ClassVar[int]
    params: _distribution_pb2.Params
    def __init__(self, params: _Optional[_Union[_distribution_pb2.Params, _Mapping]] = ...) -> None: ...

class QueryValidatorDistributionInfoRequest(_message.Message):
    __slots__ = ("validator_address",)
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    def __init__(self, validator_address: _Optional[str] = ...) -> None: ...

class QueryValidatorDistributionInfoResponse(_message.Message):
    __slots__ = ("operator_address", "self_bond_rewards", "commission")
    OPERATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    SELF_BOND_REWARDS_FIELD_NUMBER: _ClassVar[int]
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    operator_address: str
    self_bond_rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    commission: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, operator_address: _Optional[str] = ..., self_bond_rewards: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ..., commission: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class QueryValidatorOutstandingRewardsRequest(_message.Message):
    __slots__ = ("validator_address",)
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    def __init__(self, validator_address: _Optional[str] = ...) -> None: ...

class QueryValidatorOutstandingRewardsResponse(_message.Message):
    __slots__ = ("rewards",)
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    rewards: _distribution_pb2.ValidatorOutstandingRewards
    def __init__(self, rewards: _Optional[_Union[_distribution_pb2.ValidatorOutstandingRewards, _Mapping]] = ...) -> None: ...

class QueryValidatorCommissionRequest(_message.Message):
    __slots__ = ("validator_address",)
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    def __init__(self, validator_address: _Optional[str] = ...) -> None: ...

class QueryValidatorCommissionResponse(_message.Message):
    __slots__ = ("commission",)
    COMMISSION_FIELD_NUMBER: _ClassVar[int]
    commission: _distribution_pb2.ValidatorAccumulatedCommission
    def __init__(self, commission: _Optional[_Union[_distribution_pb2.ValidatorAccumulatedCommission, _Mapping]] = ...) -> None: ...

class QueryValidatorSlashesRequest(_message.Message):
    __slots__ = ("validator_address", "starting_height", "ending_height", "pagination")
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    STARTING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    ENDING_HEIGHT_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    validator_address: str
    starting_height: int
    ending_height: int
    pagination: _pagination_pb2.PageRequest
    def __init__(self, validator_address: _Optional[str] = ..., starting_height: _Optional[int] = ..., ending_height: _Optional[int] = ..., pagination: _Optional[_Union[_pagination_pb2.PageRequest, _Mapping]] = ...) -> None: ...

class QueryValidatorSlashesResponse(_message.Message):
    __slots__ = ("slashes", "pagination")
    SLASHES_FIELD_NUMBER: _ClassVar[int]
    PAGINATION_FIELD_NUMBER: _ClassVar[int]
    slashes: _containers.RepeatedCompositeFieldContainer[_distribution_pb2.ValidatorSlashEvent]
    pagination: _pagination_pb2.PageResponse
    def __init__(self, slashes: _Optional[_Iterable[_Union[_distribution_pb2.ValidatorSlashEvent, _Mapping]]] = ..., pagination: _Optional[_Union[_pagination_pb2.PageResponse, _Mapping]] = ...) -> None: ...

class QueryDelegationRewardsRequest(_message.Message):
    __slots__ = ("delegator_address", "validator_address")
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    VALIDATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    validator_address: str
    def __init__(self, delegator_address: _Optional[str] = ..., validator_address: _Optional[str] = ...) -> None: ...

class QueryDelegationRewardsResponse(_message.Message):
    __slots__ = ("rewards",)
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    rewards: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, rewards: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class QueryDelegationTotalRewardsRequest(_message.Message):
    __slots__ = ("delegator_address",)
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    def __init__(self, delegator_address: _Optional[str] = ...) -> None: ...

class QueryDelegationTotalRewardsResponse(_message.Message):
    __slots__ = ("rewards", "total")
    REWARDS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    rewards: _containers.RepeatedCompositeFieldContainer[_distribution_pb2.DelegationDelegatorReward]
    total: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, rewards: _Optional[_Iterable[_Union[_distribution_pb2.DelegationDelegatorReward, _Mapping]]] = ..., total: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...

class QueryDelegatorValidatorsRequest(_message.Message):
    __slots__ = ("delegator_address",)
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    def __init__(self, delegator_address: _Optional[str] = ...) -> None: ...

class QueryDelegatorValidatorsResponse(_message.Message):
    __slots__ = ("validators",)
    VALIDATORS_FIELD_NUMBER: _ClassVar[int]
    validators: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, validators: _Optional[_Iterable[str]] = ...) -> None: ...

class QueryDelegatorWithdrawAddressRequest(_message.Message):
    __slots__ = ("delegator_address",)
    DELEGATOR_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    delegator_address: str
    def __init__(self, delegator_address: _Optional[str] = ...) -> None: ...

class QueryDelegatorWithdrawAddressResponse(_message.Message):
    __slots__ = ("withdraw_address",)
    WITHDRAW_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    withdraw_address: str
    def __init__(self, withdraw_address: _Optional[str] = ...) -> None: ...

class QueryCommunityPoolRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class QueryCommunityPoolResponse(_message.Message):
    __slots__ = ("pool",)
    POOL_FIELD_NUMBER: _ClassVar[int]
    pool: _containers.RepeatedCompositeFieldContainer[_coin_pb2.DecCoin]
    def __init__(self, pool: _Optional[_Iterable[_Union[_coin_pb2.DecCoin, _Mapping]]] = ...) -> None: ...



from v4_proto.gogoproto import gogo_pb2 as _gogo_pb2
from v4_proto.cosmos_proto import cosmos_pb2 as _cosmos_pb2
from v4_proto.amino import amino_pb2 as _amino_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Minter(_message.Message):
    __slots__ = ("inflation", "annual_provisions")
    INFLATION_FIELD_NUMBER: _ClassVar[int]
    ANNUAL_PROVISIONS_FIELD_NUMBER: _ClassVar[int]
    inflation: str
    annual_provisions: str
    def __init__(self, inflation: _Optional[str] = ..., annual_provisions: _Optional[str] = ...) -> None: ...

class Params(_message.Message):
    __slots__ = ("mint_denom", "inflation_rate_change", "inflation_max", "inflation_min", "goal_bonded", "blocks_per_year")
    MINT_DENOM_FIELD_NUMBER: _ClassVar[int]
    INFLATION_RATE_CHANGE_FIELD_NUMBER: _ClassVar[int]
    INFLATION_MAX_FIELD_NUMBER: _ClassVar[int]
    INFLATION_MIN_FIELD_NUMBER: _ClassVar[int]
    GOAL_BONDED_FIELD_NUMBER: _ClassVar[int]
    BLOCKS_PER_YEAR_FIELD_NUMBER: _ClassVar[int]
    mint_denom: str
    inflation_rate_change: str
    inflation_max: str
    inflation_min: str
    goal_bonded: str
    blocks_per_year: int
    def __init__(self, mint_denom: _Optional[str] = ..., inflation_rate_change: _Optional[str] = ..., inflation_max: _Optional[str] = ..., inflation_min: _Optional[str] = ..., goal_bonded: _Optional[str] = ..., blocks_per_year: _Optional[int] = ...) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class PerpetualMarketType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PERPETUAL_MARKET_TYPE_UNSPECIFIED: _ClassVar[PerpetualMarketType]
    PERPETUAL_MARKET_TYPE_CROSS: _ClassVar[PerpetualMarketType]
    PERPETUAL_MARKET_TYPE_ISOLATED: _ClassVar[PerpetualMarketType]
PERPETUAL_MARKET_TYPE_UNSPECIFIED: PerpetualMarketType
PERPETUAL_MARKET_TYPE_CROSS: PerpetualMarketType
PERPETUAL_MARKET_TYPE_ISOLATED: PerpetualMarketType



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/evidence/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%cosmos/evidence/v1beta1/genesis.proto\x12\x17\x63osmos.evidence.v1beta1\x1a\x19google/protobuf/any.proto\"6\n\x0cGenesisState\x12&\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyB\x1fZ\x1d\x63osmossdk.io/x/evidence/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.evidence.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\035cosmossdk.io/x/evidence/types'
  _globals['_GENESISSTATE']._serialized_start=93
  _globals['_GENESISSTATE']._serialized_end=147
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/clob/mev.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.dydxprotocol.subaccounts import subaccount_pb2 as dydxprotocol_dot_subaccounts_dot_subaccount__pb2
from v4_proto.dydxprotocol.clob import clob_pair_pb2 as dydxprotocol_dot_clob_dot_clob__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x64ydxprotocol/clob/mev.proto\x12\x11\x64ydxprotocol.clob\x1a\x14gogoproto/gogo.proto\x1a)dydxprotocol/subaccounts/subaccount.proto\x1a!dydxprotocol/clob/clob_pair.proto\"\xb3\x02\n\x08MEVMatch\x12I\n\x19taker_order_subaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12\x15\n\rtaker_fee_ppm\x18\x02 \x01(\x05\x12I\n\x19maker_order_subaccount_id\x18\x03 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountId\x12\x1c\n\x14maker_order_subticks\x18\x04 \x01(\x04\x12\x1a\n\x12maker_order_is_buy\x18\x05 \x01(\x08\x12\x15\n\rmaker_fee_ppm\x18\x06 \x01(\x05\x12\x14\n\x0c\x63lob_pair_id\x18\x07 \x01(\r\x12\x13\n\x0b\x66ill_amount\x18\x08 \x01(\x04\"\xdf\x02\n\x13MEVLiquidationMatch\x12N\n\x18liquidated_subaccount_id\x18\x01 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12+\n#insurance_fund_delta_quote_quantums\x18\x02 \x01(\x03\x12O\n\x19maker_order_subaccount_id\x18\x03 \x01(\x0b\x32&.dydxprotocol.subaccounts.SubaccountIdB\x04\xc8\xde\x1f\x00\x12\x1c\n\x14maker_order_subticks\x18\x04 \x01(\x04\x12\x1a\n\x12maker_order_is_buy\x18\x05 \x01(\x08\x12\x15\n\rmaker_fee_ppm\x18\x06 \x01(\x05\x12\x14\n\x0c\x63lob_pair_id\x18\x07 \x01(\r\x12\x13\n\x0b\x66ill_amount\x18\x08 \x01(\x04\"V\n\x0c\x43lobMidPrice\x12\x34\n\tclob_pair\x18\x01 \x01(\x0b\x32\x1b.dydxprotocol.clob.ClobPairB\x04\xc8\xde\x1f\x00\x12\x10\n\x08subticks\x18\x02 \x01(\x04\"\x94\x01\n\x13ValidatorMevMatches\x12\x32\n\x07matches\x18\x01 \x03(\x0b\x32\x1b.dydxprotocol.clob.MEVMatchB\x04\xc8\xde\x1f\x00\x12I\n\x13liquidation_matches\x18\x02 \x03(\x0b\x32&.dydxprotocol.clob.MEVLiquidationMatchB\x04\xc8\xde\x1f\x00\"\xfc\x01\n\x14MevNodeToNodeMetrics\x12\x45\n\x15validator_mev_matches\x18\x01 \x01(\x0b\x32&.dydxprotocol.clob.ValidatorMevMatches\x12>\n\x0f\x63lob_mid_prices\x18\x02 \x03(\x0b\x32\x1f.dydxprotocol.clob.ClobMidPriceB\x04\xc8\xde\x1f\x00\x12>\n\x0e\x62p_mev_matches\x18\x03 \x01(\x0b\x32&.dydxprotocol.clob.ValidatorMevMatches\x12\x1d\n\x15proposal_receive_time\x18\x04 \x01(\x04\x42\x38Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.clob.mev_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/clob/types'
  _globals['_MEVLIQUIDATIONMATCH'].fields_by_name['liquidated_subaccount_id']._loaded_options = None
  _globals['_MEVLIQUIDATIONMATCH'].fields_by_name['liquidated_subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_MEVLIQUIDATIONMATCH'].fields_by_name['maker_order_subaccount_id']._loaded_options = None
  _globals['_MEVLIQUIDATIONMATCH'].fields_by_name['maker_order_subaccount_id']._serialized_options = b'\310\336\037\000'
  _globals['_CLOBMIDPRICE'].fields_by_name['clob_pair']._loaded_options = None
  _globals['_CLOBMIDPRICE'].fields_by_name['clob_pair']._serialized_options = b'\310\336\037\000'
  _globals['_VALIDATORMEVMATCHES'].fields_by_name['matches']._loaded_options = None
  _globals['_VALIDATORMEVMATCHES'].fields_by_name['matches']._serialized_options = b'\310\336\037\000'
  _globals['_VALIDATORMEVMATCHES'].fields_by_name['liquidation_matches']._loaded_options = None
  _globals['_VALIDATORMEVMATCHES'].fields_by_name['liquidation_matches']._serialized_options = b'\310\336\037\000'
  _globals['_MEVNODETONODEMETRICS'].fields_by_name['clob_mid_prices']._loaded_options = None
  _globals['_MEVNODETONODEMETRICS'].fields_by_name['clob_mid_prices']._serialized_options = b'\310\336\037\000'
  _globals['_MEVMATCH']._serialized_start=151
  _globals['_MEVMATCH']._serialized_end=458
  _globals['_MEVLIQUIDATIONMATCH']._serialized_start=461
  _globals['_MEVLIQUIDATIONMATCH']._serialized_end=812
  _globals['_CLOBMIDPRICE']._serialized_start=814
  _globals['_CLOBMIDPRICE']._serialized_end=900
  _globals['_VALIDATORMEVMATCHES']._serialized_start=903
  _globals['_VALIDATORMEVMATCHES']._serialized_end=1051
  _globals['_MEVNODETONODEMETRICS']._serialized_start=1054
  _globals['_MEVNODETONODEMETRICS']._serialized_end=1306
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vest/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.dydxprotocol.vest import vest_entry_pb2 as dydxprotocol_dot_vest_dot_vest__entry__pb2
from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x64ydxprotocol/vest/query.proto\x12\x11\x64ydxprotocol.vest\x1a\x1cgoogle/api/annotations.proto\x1a\"dydxprotocol/vest/vest_entry.proto\x1a\x14gogoproto/gogo.proto\"/\n\x15QueryVestEntryRequest\x12\x16\n\x0evester_account\x18\x01 \x01(\t\"K\n\x16QueryVestEntryResponse\x12\x31\n\x05\x65ntry\x18\x01 \x01(\x0b\x32\x1c.dydxprotocol.vest.VestEntryB\x04\xc8\xde\x1f\x00\x32\x94\x01\n\x05Query\x12\x8a\x01\n\tVestEntry\x12(.dydxprotocol.vest.QueryVestEntryRequest\x1a).dydxprotocol.vest.QueryVestEntryResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /dydxprotocol/v4/vest/vest_entryB8Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vest.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z6github.com/dydxprotocol/v4-chain/protocol/x/vest/types'
  _globals['_QUERYVESTENTRYRESPONSE'].fields_by_name['entry']._loaded_options = None
  _globals['_QUERYVESTENTRYRESPONSE'].fields_by_name['entry']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['VestEntry']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VestEntry']._serialized_options = b'\202\323\344\223\002\"\022 /dydxprotocol/v4/vest/vest_entry'
  _globals['_QUERYVESTENTRYREQUEST']._serialized_start=140
  _globals['_QUERYVESTENTRYREQUEST']._serialized_end=187
  _globals['_QUERYVESTENTRYRESPONSE']._serialized_start=189
  _globals['_QUERYVESTENTRYRESPONSE']._serialized_end=264
  _globals['_QUERY']._serialized_start=267
  _globals['_QUERY']._serialized_end=415
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/vault/vault.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x64ydxprotocol/vault/vault.proto\x12\x12\x64ydxprotocol.vault\x1a\x14gogoproto/gogo.proto\"F\n\x07VaultId\x12+\n\x04type\x18\x01 \x01(\x0e\x32\x1d.dydxprotocol.vault.VaultType\x12\x0e\n\x06number\x18\x02 \x01(\r\"i\n\tNumShares\x12\\\n\nnum_shares\x18\x02 \x01(\x0c\x42H\xc8\xde\x1f\x00\xda\xde\x1f@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt*<\n\tVaultType\x12\x1a\n\x16VAULT_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fVAULT_TYPE_CLOB\x10\x01\x42\x39Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.vault.vault_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z7github.com/dydxprotocol/v4-chain/protocol/x/vault/types'
  _globals['_NUMSHARES'].fields_by_name['num_shares']._loaded_options = None
  _globals['_NUMSHARES'].fields_by_name['num_shares']._serialized_options = b'\310\336\037\000\332\336\037@github.com/dydxprotocol/v4-chain/protocol/dtypes.SerializableInt'
  _globals['_VAULTTYPE']._serialized_start=255
  _globals['_VAULTTYPE']._serialized_end=315
  _globals['_VAULTID']._serialized_start=76
  _globals['_VAULTID']._serialized_end=146
  _globals['_NUMSHARES']._serialized_start=148
  _globals['_NUMSHARES']._serialized_end=253
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from v4_proto.dydxprotocol.clob import tx_pb2 as dydxprotocol_dot_clob_dot_tx__pb2

GRPC_GENERATED_VERSION = '1.64.1'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in dydxprotocol/clob/tx_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class MsgStub(object):
    """Msg defines the Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProposedOperations = channel.unary_unary(
                '/dydxprotocol.clob.Msg/ProposedOperations',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperations.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperationsResponse.FromString,
                _registered_method=True)
        self.PlaceOrder = channel.unary_unary(
                '/dydxprotocol.clob.Msg/PlaceOrder',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrder.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrderResponse.FromString,
                _registered_method=True)
        self.CancelOrder = channel.unary_unary(
                '/dydxprotocol.clob.Msg/CancelOrder',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrder.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrderResponse.FromString,
                _registered_method=True)
        self.BatchCancel = channel.unary_unary(
                '/dydxprotocol.clob.Msg/BatchCancel',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancel.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancelResponse.FromString,
                _registered_method=True)
        self.CreateClobPair = channel.unary_unary(
                '/dydxprotocol.clob.Msg/CreateClobPair',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPair.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPairResponse.FromString,
                _registered_method=True)
        self.UpdateClobPair = channel.unary_unary(
                '/dydxprotocol.clob.Msg/UpdateClobPair',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPair.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPairResponse.FromString,
                _registered_method=True)
        self.UpdateEquityTierLimitConfiguration = channel.unary_unary(
                '/dydxprotocol.clob.Msg/UpdateEquityTierLimitConfiguration',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfiguration.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfigurationResponse.FromString,
                _registered_method=True)
        self.UpdateBlockRateLimitConfiguration = channel.unary_unary(
                '/dydxprotocol.clob.Msg/UpdateBlockRateLimitConfiguration',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfiguration.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfigurationResponse.FromString,
                _registered_method=True)
        self.UpdateLiquidationsConfig = channel.unary_unary(
                '/dydxprotocol.clob.Msg/UpdateLiquidationsConfig',
                request_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfig.SerializeToString,
                response_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfigResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the Msg service.
    """

    def ProposedOperations(self, request, context):
        """ProposedOperations is a temporary message used by block proposers
        for matching orders as part of the ABCI++ workaround.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PlaceOrder(self, request, context):
        """PlaceOrder allows accounts to place orders on the orderbook.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelOrder(self, request, context):
        """CancelOrder allows accounts to cancel existing orders on the orderbook.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BatchCancel(self, request, context):
        """BatchCancel allows accounts to cancel a batch of orders on the orderbook.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateClobPair(self, request, context):
        """CreateClobPair creates a new clob pair.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateClobPair(self, request, context):
        """UpdateClobPair sets the status of a clob pair. Should return an error
        if the authority is not in the clob keeper's set of authorities,
        if the ClobPair id is not found in state, or if the update includes
        an unsupported status transition.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateEquityTierLimitConfiguration(self, request, context):
        """UpdateEquityTierLimitConfiguration updates the equity tier limit
        configuration in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBlockRateLimitConfiguration(self, request, context):
        """UpdateBlockRateLimitConfiguration updates the block rate limit
        configuration in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLiquidationsConfig(self, request, context):
        """UpdateLiquidationsConfig updates the liquidations configuration in state.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ProposedOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ProposedOperations,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperations.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperationsResponse.SerializeToString,
            ),
            'PlaceOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.PlaceOrder,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrder.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrderResponse.SerializeToString,
            ),
            'CancelOrder': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelOrder,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrder.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrderResponse.SerializeToString,
            ),
            'BatchCancel': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchCancel,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancel.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancelResponse.SerializeToString,
            ),
            'CreateClobPair': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateClobPair,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPair.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPairResponse.SerializeToString,
            ),
            'UpdateClobPair': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateClobPair,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPair.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPairResponse.SerializeToString,
            ),
            'UpdateEquityTierLimitConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateEquityTierLimitConfiguration,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfiguration.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfigurationResponse.SerializeToString,
            ),
            'UpdateBlockRateLimitConfiguration': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBlockRateLimitConfiguration,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfiguration.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfigurationResponse.SerializeToString,
            ),
            'UpdateLiquidationsConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLiquidationsConfig,
                    request_deserializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfig.FromString,
                    response_serializer=dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfigResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dydxprotocol.clob.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('dydxprotocol.clob.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the Msg service.
    """

    @staticmethod
    def ProposedOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/ProposedOperations',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperations.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgProposedOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PlaceOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/PlaceOrder',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrder.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgPlaceOrderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelOrder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/CancelOrder',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrder.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgCancelOrderResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BatchCancel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/BatchCancel',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancel.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgBatchCancelResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateClobPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/CreateClobPair',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPair.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgCreateClobPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateClobPair(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/UpdateClobPair',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPair.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateClobPairResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateEquityTierLimitConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/UpdateEquityTierLimitConfiguration',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfiguration.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateEquityTierLimitConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateBlockRateLimitConfiguration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/UpdateBlockRateLimitConfiguration',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfiguration.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateBlockRateLimitConfigurationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateLiquidationsConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/dydxprotocol.clob.Msg/UpdateLiquidationsConfig',
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfig.SerializeToString,
            dydxprotocol_dot_clob_dot_tx__pb2.MsgUpdateLiquidationsConfigResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/multisig/v1beta1/multisig.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-cosmos/crypto/multisig/v1beta1/multisig.proto\x12\x1e\x63osmos.crypto.multisig.v1beta1\x1a\x14gogoproto/gogo.proto\"*\n\x0eMultiSignature\x12\x12\n\nsignatures\x18\x01 \x03(\x0c:\x04\xd0\xa1\x1f\x01\"A\n\x0f\x43ompactBitArray\x12\x19\n\x11\x65xtra_bits_stored\x18\x01 \x01(\r\x12\r\n\x05\x65lems\x18\x02 \x01(\x0c:\x04\x98\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/crypto/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.crypto.multisig.v1beta1.multisig_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z)github.com/cosmos/cosmos-sdk/crypto/types'
  _globals['_MULTISIGNATURE']._loaded_options = None
  _globals['_MULTISIGNATURE']._serialized_options = b'\320\241\037\001'
  _globals['_COMPACTBITARRAY']._loaded_options = None
  _globals['_COMPACTBITARRAY']._serialized_options = b'\230\240\037\000'
  _globals['_MULTISIGNATURE']._serialized_start=103
  _globals['_MULTISIGNATURE']._serialized_end=145
  _globals['_COMPACTBITARRAY']._serialized_start=147
  _globals['_COMPACTBITARRAY']._serialized_end=212
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/group/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from v4_proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from v4_proto.cosmos.group.v1 import types_pb2 as cosmos_dot_group_dot_v1_dot_types__pb2
from v4_proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from v4_proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x63osmos/group/v1/tx.proto\x12\x0f\x63osmos.group.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x19google/protobuf/any.proto\x1a\x1b\x63osmos/group/v1/types.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x11\x61mino/amino.proto\"\xb1\x01\n\x0eMsgCreateGroup\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\x07members\x18\x02 \x03(\x0b\x32\x1e.cosmos.group.v1.MemberRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x10\n\x08metadata\x18\x03 \x01(\t:(\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\x19\x63osmos-sdk/MsgCreateGroup\"*\n\x16MsgCreateGroupResponse\x12\x10\n\x08group_id\x18\x01 \x01(\x04\"\xc6\x01\n\x15MsgUpdateGroupMembers\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04\x12\x41\n\x0emember_updates\x18\x03 \x03(\x0b\x32\x1e.cosmos.group.v1.MemberRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01:/\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0* cosmos-sdk/MsgUpdateGroupMembers\"\x1f\n\x1dMsgUpdateGroupMembersResponse\"\xac\x01\n\x13MsgUpdateGroupAdmin\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04\x12+\n\tnew_admin\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:-\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\x1e\x63osmos-sdk/MsgUpdateGroupAdmin\"\x1d\n\x1bMsgUpdateGroupAdminResponse\"\x97\x01\n\x16MsgUpdateGroupMetadata\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04\x12\x10\n\x08metadata\x18\x03 \x01(\t:0\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*!cosmos-sdk/MsgUpdateGroupMetadata\" \n\x1eMsgUpdateGroupMetadataResponse\"\xea\x01\n\x14MsgCreateGroupPolicy\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12Q\n\x0f\x64\x65\x63ision_policy\x18\x04 \x01(\x0b\x32\x14.google.protobuf.AnyB\"\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy:2\x88\xa0\x1f\x00\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\x1f\x63osmos-sdk/MsgCreateGroupPolicy\"I\n\x1cMsgCreateGroupPolicyResponse\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\xde\x01\n\x19MsgUpdateGroupPolicyAdmin\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x14group_policy_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\tnew_admin\x18\x03 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:3\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*$cosmos-sdk/MsgUpdateGroupPolicyAdmin\"#\n!MsgUpdateGroupPolicyAdminResponse\"\xe0\x02\n\x18MsgCreateGroupWithPolicy\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12:\n\x07members\x18\x02 \x03(\x0b\x32\x1e.cosmos.group.v1.MemberRequestB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01\x12\x16\n\x0egroup_metadata\x18\x03 \x01(\t\x12\x1d\n\x15group_policy_metadata\x18\x04 \x01(\t\x12\x1d\n\x15group_policy_as_admin\x18\x05 \x01(\x08\x12Q\n\x0f\x64\x65\x63ision_policy\x18\x06 \x01(\x0b\x32\x14.google.protobuf.AnyB\"\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy:6\x88\xa0\x1f\x00\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*#cosmos-sdk/MsgCreateGroupWithPolicy\"l\n MsgCreateGroupWithPolicyResponse\x12\x10\n\x08group_id\x18\x01 \x01(\x04\x12\x36\n\x14group_policy_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\"\x94\x02\n\"MsgUpdateGroupPolicyDecisionPolicy\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x14group_policy_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12Q\n\x0f\x64\x65\x63ision_policy\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyB\"\xca\xb4-\x1e\x63osmos.group.v1.DecisionPolicy::\x88\xa0\x1f\x00\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\'cosmos-sdk/MsgUpdateGroupDecisionPolicy\",\n*MsgUpdateGroupPolicyDecisionPolicyResponse\"\xc9\x01\n\x1cMsgUpdateGroupPolicyMetadata\x12\'\n\x05\x61\x64min\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x36\n\x14group_policy_address\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08metadata\x18\x03 \x01(\t:6\x82\xe7\xb0*\x05\x61\x64min\x8a\xe7\xb0*\'cosmos-sdk/MsgUpdateGroupPolicyMetadata\"&\n$MsgUpdateGroupPolicyMetadataResponse\"\x98\x02\n\x11MsgSubmitProposal\x12\x36\n\x14group_policy_address\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x11\n\tproposers\x18\x02 \x03(\t\x12\x10\n\x08metadata\x18\x03 \x01(\t\x12&\n\x08messages\x18\x04 \x03(\x0b\x32\x14.google.protobuf.Any\x12#\n\x04\x65xec\x18\x05 \x01(\x0e\x32\x15.cosmos.group.v1.Exec\x12\r\n\x05title\x18\x06 \x01(\t\x12\x0f\n\x07summary\x18\x07 \x01(\t:9\x88\xa0\x1f\x00\x82\xe7\xb0*\tproposers\x8a\xe7\xb0*\"cosmos-sdk/group/MsgSubmitProposal\"0\n\x19MsgSubmitProposalResponse\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\"\x8c\x01\n\x13MsgWithdrawProposal\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12)\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:5\x82\xe7\xb0*\x07\x61\x64\x64ress\x8a\xe7\xb0*$cosmos-sdk/group/MsgWithdrawProposal\"\x1d\n\x1bMsgWithdrawProposalResponse\"\xd4\x01\n\x07MsgVote\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12\'\n\x05voter\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12+\n\x06option\x18\x03 \x01(\x0e\x32\x1b.cosmos.group.v1.VoteOption\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12#\n\x04\x65xec\x18\x05 \x01(\x0e\x32\x15.cosmos.group.v1.Exec:\'\x82\xe7\xb0*\x05voter\x8a\xe7\xb0*\x18\x63osmos-sdk/group/MsgVote\"\x11\n\x0fMsgVoteResponse\"v\n\x07MsgExec\x12\x13\n\x0bproposal_id\x18\x01 \x01(\x04\x12*\n\x08\x65xecutor\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString:*\x82\xe7\xb0*\x08\x65xecutor\x8a\xe7\xb0*\x18\x63osmos-sdk/group/MsgExec\"J\n\x0fMsgExecResponse\x12\x37\n\x06result\x18\x02 \x01(\x0e\x32\'.cosmos.group.v1.ProposalExecutorResult\"}\n\rMsgLeaveGroup\x12)\n\x07\x61\x64\x64ress\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressString\x12\x10\n\x08group_id\x18\x02 \x01(\x04:/\x82\xe7\xb0*\x07\x61\x64\x64ress\x8a\xe7\xb0*\x1e\x63osmos-sdk/group/MsgLeaveGroup\"\x17\n\x15MsgLeaveGroupResponse**\n\x04\x45xec\x12\x14\n\x10\x45XEC_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45XEC_TRY\x10\x01\x32\xca\x0b\n\x03Msg\x12W\n\x0b\x43reateGroup\x12\x1f.cosmos.group.v1.MsgCreateGroup\x1a\'.cosmos.group.v1.MsgCreateGroupResponse\x12l\n\x12UpdateGroupMembers\x12&.cosmos.group.v1.MsgUpdateGroupMembers\x1a..cosmos.group.v1.MsgUpdateGroupMembersResponse\x12\x66\n\x10UpdateGroupAdmin\x12$.cosmos.group.v1.MsgUpdateGroupAdmin\x1a,.cosmos.group.v1.MsgUpdateGroupAdminResponse\x12o\n\x13UpdateGroupMetadata\x12\'.cosmos.group.v1.MsgUpdateGroupMetadata\x1a/.cosmos.group.v1.MsgUpdateGroupMetadataResponse\x12i\n\x11\x43reateGroupPolicy\x12%.cosmos.group.v1.MsgCreateGroupPolicy\x1a-.cosmos.group.v1.MsgCreateGroupPolicyResponse\x12u\n\x15\x43reateGroupWithPolicy\x12).cosmos.group.v1.MsgCreateGroupWithPolicy\x1a\x31.cosmos.group.v1.MsgCreateGroupWithPolicyResponse\x12x\n\x16UpdateGroupPolicyAdmin\x12*.cosmos.group.v1.MsgUpdateGroupPolicyAdmin\x1a\x32.cosmos.group.v1.MsgUpdateGroupPolicyAdminResponse\x12\x93\x01\n\x1fUpdateGroupPolicyDecisionPolicy\x12\x33.cosmos.group.v1.MsgUpdateGroupPolicyDecisionPolicy\x1a;.cosmos.group.v1.MsgUpdateGroupPolicyDecisionPolicyResponse\x12\x81\x01\n\x19UpdateGroupPolicyMetadata\x12-.cosmos.group.v1.MsgUpdateGroupPolicyMetadata\x1a\x35.cosmos.group.v1.MsgUpdateGroupPolicyMetadataResponse\x12`\n\x0eSubmitProposal\x12\".cosmos.group.v1.MsgSubmitProposal\x1a*.cosmos.group.v1.MsgSubmitProposalResponse\x12\x66\n\x10WithdrawProposal\x12$.cosmos.group.v1.MsgWithdrawProposal\x1a,.cosmos.group.v1.MsgWithdrawProposalResponse\x12\x42\n\x04Vote\x12\x18.cosmos.group.v1.MsgVote\x1a .cosmos.group.v1.MsgVoteResponse\x12\x42\n\x04\x45xec\x12\x18.cosmos.group.v1.MsgExec\x1a .cosmos.group.v1.MsgExecResponse\x12T\n\nLeaveGroup\x12\x1e.cosmos.group.v1.MsgLeaveGroup\x1a&.cosmos.group.v1.MsgLeaveGroupResponse\x1a\x05\x80\xe7\xb0*\x01\x42&Z$github.com/cosmos/cosmos-sdk/x/groupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.group.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z$github.com/cosmos/cosmos-sdk/x/group'
  _globals['_MSGCREATEGROUP'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGCREATEGROUP'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEGROUP'].fields_by_name['members']._loaded_options = None
  _globals['_MSGCREATEGROUP'].fields_by_name['members']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEGROUP']._loaded_options = None
  _globals['_MSGCREATEGROUP']._serialized_options = b'\202\347\260*\005admin\212\347\260*\031cosmos-sdk/MsgCreateGroup'
  _globals['_MSGUPDATEGROUPMEMBERS'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPMEMBERS'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPMEMBERS'].fields_by_name['member_updates']._loaded_options = None
  _globals['_MSGUPDATEGROUPMEMBERS'].fields_by_name['member_updates']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGUPDATEGROUPMEMBERS']._loaded_options = None
  _globals['_MSGUPDATEGROUPMEMBERS']._serialized_options = b'\202\347\260*\005admin\212\347\260* cosmos-sdk/MsgUpdateGroupMembers'
  _globals['_MSGUPDATEGROUPADMIN'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPADMIN'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPADMIN'].fields_by_name['new_admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPADMIN'].fields_by_name['new_admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPADMIN']._loaded_options = None
  _globals['_MSGUPDATEGROUPADMIN']._serialized_options = b'\202\347\260*\005admin\212\347\260*\036cosmos-sdk/MsgUpdateGroupAdmin'
  _globals['_MSGUPDATEGROUPMETADATA'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPMETADATA'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPMETADATA']._loaded_options = None
  _globals['_MSGUPDATEGROUPMETADATA']._serialized_options = b'\202\347\260*\005admin\212\347\260*!cosmos-sdk/MsgUpdateGroupMetadata'
  _globals['_MSGCREATEGROUPPOLICY'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGCREATEGROUPPOLICY'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEGROUPPOLICY'].fields_by_name['decision_policy']._loaded_options = None
  _globals['_MSGCREATEGROUPPOLICY'].fields_by_name['decision_policy']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy'
  _globals['_MSGCREATEGROUPPOLICY']._loaded_options = None
  _globals['_MSGCREATEGROUPPOLICY']._serialized_options = b'\210\240\037\000\202\347\260*\005admin\212\347\260*\037cosmos-sdk/MsgCreateGroupPolicy'
  _globals['_MSGCREATEGROUPPOLICYRESPONSE'].fields_by_name['address']._loaded_options = None
  _globals['_MSGCREATEGROUPPOLICYRESPONSE'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['new_admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYADMIN'].fields_by_name['new_admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYADMIN']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYADMIN']._serialized_options = b'\202\347\260*\005admin\212\347\260*$cosmos-sdk/MsgUpdateGroupPolicyAdmin'
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['members']._loaded_options = None
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['members']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['decision_policy']._loaded_options = None
  _globals['_MSGCREATEGROUPWITHPOLICY'].fields_by_name['decision_policy']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy'
  _globals['_MSGCREATEGROUPWITHPOLICY']._loaded_options = None
  _globals['_MSGCREATEGROUPWITHPOLICY']._serialized_options = b'\210\240\037\000\202\347\260*\005admin\212\347\260*#cosmos-sdk/MsgCreateGroupWithPolicy'
  _globals['_MSGCREATEGROUPWITHPOLICYRESPONSE'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_MSGCREATEGROUPWITHPOLICYRESPONSE'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['decision_policy']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY'].fields_by_name['decision_policy']._serialized_options = b'\312\264-\036cosmos.group.v1.DecisionPolicy'
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY']._serialized_options = b'\210\240\037\000\202\347\260*\005admin\212\347\260*\'cosmos-sdk/MsgUpdateGroupDecisionPolicy'
  _globals['_MSGUPDATEGROUPPOLICYMETADATA'].fields_by_name['admin']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYMETADATA'].fields_by_name['admin']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYMETADATA'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYMETADATA'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEGROUPPOLICYMETADATA']._loaded_options = None
  _globals['_MSGUPDATEGROUPPOLICYMETADATA']._serialized_options = b'\202\347\260*\005admin\212\347\260*\'cosmos-sdk/MsgUpdateGroupPolicyMetadata'
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['group_policy_address']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL'].fields_by_name['group_policy_address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGSUBMITPROPOSAL']._loaded_options = None
  _globals['_MSGSUBMITPROPOSAL']._serialized_options = b'\210\240\037\000\202\347\260*\tproposers\212\347\260*\"cosmos-sdk/group/MsgSubmitProposal'
  _globals['_MSGWITHDRAWPROPOSAL'].fields_by_name['address']._loaded_options = None
  _globals['_MSGWITHDRAWPROPOSAL'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGWITHDRAWPROPOSAL']._loaded_options = None
  _globals['_MSGWITHDRAWPROPOSAL']._serialized_options = b'\202\347\260*\007address\212\347\260*$cosmos-sdk/group/MsgWithdrawProposal'
  _globals['_MSGVOTE'].fields_by_name['voter']._loaded_options = None
  _globals['_MSGVOTE'].fields_by_name['voter']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGVOTE']._loaded_options = None
  _globals['_MSGVOTE']._serialized_options = b'\202\347\260*\005voter\212\347\260*\030cosmos-sdk/group/MsgVote'
  _globals['_MSGEXEC'].fields_by_name['executor']._loaded_options = None
  _globals['_MSGEXEC'].fields_by_name['executor']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGEXEC']._loaded_options = None
  _globals['_MSGEXEC']._serialized_options = b'\202\347\260*\010executor\212\347\260*\030cosmos-sdk/group/MsgExec'
  _globals['_MSGLEAVEGROUP'].fields_by_name['address']._loaded_options = None
  _globals['_MSGLEAVEGROUP'].fields_by_name['address']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGLEAVEGROUP']._loaded_options = None
  _globals['_MSGLEAVEGROUP']._serialized_options = b'\202\347\260*\007address\212\347\260*\036cosmos-sdk/group/MsgLeaveGroup'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_EXEC']._serialized_start=3743
  _globals['_EXEC']._serialized_end=3785
  _globals['_MSGCREATEGROUP']._serialized_start=195
  _globals['_MSGCREATEGROUP']._serialized_end=372
  _globals['_MSGCREATEGROUPRESPONSE']._serialized_start=374
  _globals['_MSGCREATEGROUPRESPONSE']._serialized_end=416
  _globals['_MSGUPDATEGROUPMEMBERS']._serialized_start=419
  _globals['_MSGUPDATEGROUPMEMBERS']._serialized_end=617
  _globals['_MSGUPDATEGROUPMEMBERSRESPONSE']._serialized_start=619
  _globals['_MSGUPDATEGROUPMEMBERSRESPONSE']._serialized_end=650
  _globals['_MSGUPDATEGROUPADMIN']._serialized_start=653
  _globals['_MSGUPDATEGROUPADMIN']._serialized_end=825
  _globals['_MSGUPDATEGROUPADMINRESPONSE']._serialized_start=827
  _globals['_MSGUPDATEGROUPADMINRESPONSE']._serialized_end=856
  _globals['_MSGUPDATEGROUPMETADATA']._serialized_start=859
  _globals['_MSGUPDATEGROUPMETADATA']._serialized_end=1010
  _globals['_MSGUPDATEGROUPMETADATARESPONSE']._serialized_start=1012
  _globals['_MSGUPDATEGROUPMETADATARESPONSE']._serialized_end=1044
  _globals['_MSGCREATEGROUPPOLICY']._serialized_start=1047
  _globals['_MSGCREATEGROUPPOLICY']._serialized_end=1281
  _globals['_MSGCREATEGROUPPOLICYRESPONSE']._serialized_start=1283
  _globals['_MSGCREATEGROUPPOLICYRESPONSE']._serialized_end=1356
  _globals['_MSGUPDATEGROUPPOLICYADMIN']._serialized_start=1359
  _globals['_MSGUPDATEGROUPPOLICYADMIN']._serialized_end=1581
  _globals['_MSGUPDATEGROUPPOLICYADMINRESPONSE']._serialized_start=1583
  _globals['_MSGUPDATEGROUPPOLICYADMINRESPONSE']._serialized_end=1618
  _globals['_MSGCREATEGROUPWITHPOLICY']._serialized_start=1621
  _globals['_MSGCREATEGROUPWITHPOLICY']._serialized_end=1973
  _globals['_MSGCREATEGROUPWITHPOLICYRESPONSE']._serialized_start=1975
  _globals['_MSGCREATEGROUPWITHPOLICYRESPONSE']._serialized_end=2083
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY']._serialized_start=2086
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICY']._serialized_end=2362
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICYRESPONSE']._serialized_start=2364
  _globals['_MSGUPDATEGROUPPOLICYDECISIONPOLICYRESPONSE']._serialized_end=2408
  _globals['_MSGUPDATEGROUPPOLICYMETADATA']._serialized_start=2411
  _globals['_MSGUPDATEGROUPPOLICYMETADATA']._serialized_end=2612
  _globals['_MSGUPDATEGROUPPOLICYMETADATARESPONSE']._serialized_start=2614
  _globals['_MSGUPDATEGROUPPOLICYMETADATARESPONSE']._serialized_end=2652
  _globals['_MSGSUBMITPROPOSAL']._serialized_start=2655
  _globals['_MSGSUBMITPROPOSAL']._serialized_end=2935
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_start=2937
  _globals['_MSGSUBMITPROPOSALRESPONSE']._serialized_end=2985
  _globals['_MSGWITHDRAWPROPOSAL']._serialized_start=2988
  _globals['_MSGWITHDRAWPROPOSAL']._serialized_end=3128
  _globals['_MSGWITHDRAWPROPOSALRESPONSE']._serialized_start=3130
  _globals['_MSGWITHDRAWPROPOSALRESPONSE']._serialized_end=3159
  _globals['_MSGVOTE']._serialized_start=3162
  _globals['_MSGVOTE']._serialized_end=3374
  _globals['_MSGVOTERESPONSE']._serialized_start=3376
  _globals['_MSGVOTERESPONSE']._serialized_end=3393
  _globals['_MSGEXEC']._serialized_start=3395
  _globals['_MSGEXEC']._serialized_end=3513
  _globals['_MSGEXECRESPONSE']._serialized_start=3515
  _globals['_MSGEXECRESPONSE']._serialized_end=3589
  _globals['_MSGLEAVEGROUP']._serialized_start=3591
  _globals['_MSGLEAVEGROUP']._serialized_end=3716
  _globals['_MSGLEAVEGROUPRESPONSE']._serialized_start=3718
  _globals['_MSGLEAVEGROUPRESPONSE']._serialized_end=3741
  _globals['_MSG']._serialized_start=3788
  _globals['_MSG']._serialized_end=5270
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/upgrade/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from v4_proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from v4_proto.cosmos.upgrade.v1beta1 import upgrade_pb2 as cosmos_dot_upgrade_dot_v1beta1_dot_upgrade__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"cosmos/upgrade/v1beta1/query.proto\x12\x16\x63osmos.upgrade.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a$cosmos/upgrade/v1beta1/upgrade.proto\"\x19\n\x17QueryCurrentPlanRequest\"F\n\x18QueryCurrentPlanResponse\x12*\n\x04plan\x18\x01 \x01(\x0b\x32\x1c.cosmos.upgrade.v1beta1.Plan\"\'\n\x17QueryAppliedPlanRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\"*\n\x18QueryAppliedPlanResponse\x12\x0e\n\x06height\x18\x01 \x01(\x03\"=\n\"QueryUpgradedConsensusStateRequest\x12\x13\n\x0blast_height\x18\x01 \x01(\x03:\x02\x18\x01\"Q\n#QueryUpgradedConsensusStateResponse\x12 \n\x18upgraded_consensus_state\x18\x02 \x01(\x0c:\x02\x18\x01J\x04\x08\x01\x10\x02\"1\n\x1aQueryModuleVersionsRequest\x12\x13\n\x0bmodule_name\x18\x01 \x01(\t\"]\n\x1bQueryModuleVersionsResponse\x12>\n\x0fmodule_versions\x18\x01 \x03(\x0b\x32%.cosmos.upgrade.v1beta1.ModuleVersion\"\x17\n\x15QueryAuthorityRequest\")\n\x16QueryAuthorityResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t2\xf4\x06\n\x05Query\x12\x9e\x01\n\x0b\x43urrentPlan\x12/.cosmos.upgrade.v1beta1.QueryCurrentPlanRequest\x1a\x30.cosmos.upgrade.v1beta1.QueryCurrentPlanResponse\",\x82\xd3\xe4\x93\x02&\x12$/cosmos/upgrade/v1beta1/current_plan\x12\xa5\x01\n\x0b\x41ppliedPlan\x12/.cosmos.upgrade.v1beta1.QueryAppliedPlanRequest\x1a\x30.cosmos.upgrade.v1beta1.QueryAppliedPlanResponse\"3\x82\xd3\xe4\x93\x02-\x12+/cosmos/upgrade/v1beta1/applied_plan/{name}\x12\xdc\x01\n\x16UpgradedConsensusState\x12:.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateRequest\x1a;.cosmos.upgrade.v1beta1.QueryUpgradedConsensusStateResponse\"I\x88\x02\x01\x82\xd3\xe4\x93\x02@\x12>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}\x12\xaa\x01\n\x0eModuleVersions\x12\x32.cosmos.upgrade.v1beta1.QueryModuleVersionsRequest\x1a\x33.cosmos.upgrade.v1beta1.QueryModuleVersionsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/cosmos/upgrade/v1beta1/module_versions\x12\x95\x01\n\tAuthority\x12-.cosmos.upgrade.v1beta1.QueryAuthorityRequest\x1a..cosmos.upgrade.v1beta1.QueryAuthorityResponse\")\x82\xd3\xe4\x93\x02#\x12!/cosmos/upgrade/v1beta1/authorityB\x1eZ\x1c\x63osmossdk.io/x/upgrade/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.upgrade.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\034cosmossdk.io/x/upgrade/types'
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._loaded_options = None
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_options = b'\030\001'
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._loaded_options = None
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_options = b'\030\001'
  _globals['_QUERY'].methods_by_name['CurrentPlan']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CurrentPlan']._serialized_options = b'\202\323\344\223\002&\022$/cosmos/upgrade/v1beta1/current_plan'
  _globals['_QUERY'].methods_by_name['AppliedPlan']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AppliedPlan']._serialized_options = b'\202\323\344\223\002-\022+/cosmos/upgrade/v1beta1/applied_plan/{name}'
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['UpgradedConsensusState']._serialized_options = b'\210\002\001\202\323\344\223\002@\022>/cosmos/upgrade/v1beta1/upgraded_consensus_state/{last_height}'
  _globals['_QUERY'].methods_by_name['ModuleVersions']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ModuleVersions']._serialized_options = b'\202\323\344\223\002)\022\'/cosmos/upgrade/v1beta1/module_versions'
  _globals['_QUERY'].methods_by_name['Authority']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Authority']._serialized_options = b'\202\323\344\223\002#\022!/cosmos/upgrade/v1beta1/authority'
  _globals['_QUERYCURRENTPLANREQUEST']._serialized_start=130
  _globals['_QUERYCURRENTPLANREQUEST']._serialized_end=155
  _globals['_QUERYCURRENTPLANRESPONSE']._serialized_start=157
  _globals['_QUERYCURRENTPLANRESPONSE']._serialized_end=227
  _globals['_QUERYAPPLIEDPLANREQUEST']._serialized_start=229
  _globals['_QUERYAPPLIEDPLANREQUEST']._serialized_end=268
  _globals['_QUERYAPPLIEDPLANRESPONSE']._serialized_start=270
  _globals['_QUERYAPPLIEDPLANRESPONSE']._serialized_end=312
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_start=314
  _globals['_QUERYUPGRADEDCONSENSUSSTATEREQUEST']._serialized_end=375
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_start=377
  _globals['_QUERYUPGRADEDCONSENSUSSTATERESPONSE']._serialized_end=458
  _globals['_QUERYMODULEVERSIONSREQUEST']._serialized_start=460
  _globals['_QUERYMODULEVERSIONSREQUEST']._serialized_end=509
  _globals['_QUERYMODULEVERSIONSRESPONSE']._serialized_start=511
  _globals['_QUERYMODULEVERSIONSRESPONSE']._serialized_end=604
  _globals['_QUERYAUTHORITYREQUEST']._serialized_start=606
  _globals['_QUERYAUTHORITYREQUEST']._serialized_end=629
  _globals['_QUERYAUTHORITYRESPONSE']._serialized_start=631
  _globals['_QUERYAUTHORITYRESPONSE']._serialized_end=672
  _globals['_QUERY']._serialized_start=675
  _globals['_QUERY']._serialized_end=1559
# @@protoc_insertion_point(module_scope)
